===============
Release History
===============

v1.0.1 (2024-10-03)
-------------------
Bugfixes:

- Fixed a bug that stopped benchmark evaluation with user-specified streamflow variable names.


Initial Release (2024-09-12)
----------------------------
Released the package with core functionality:

- Capability to work with pandas DataFrames (e.g., CSV data) and xarray DataSets (e.g., netCDF data).
- Capability to create 19 benchmark timeseries for hydrologic models.
- Documention on readthedocs.io.

Additional Features:

- Capability to calculate 4 performance metrics for the benchmark simulations.
- Capability to run a simple degree-day model for snow accumulation and melt simulation.

Notes:

- Release coincides with submission of a related commentary to Hydrologic Processes.
